==> haskell-yesod-1.6.2.1-385-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod
version:              1.6.2.1
visibility:           public
id:                   yesod-1.6.2.1-7W66MLs0ubi3XMLwAZ2Mmb
key:                  yesod-1.6.2.1-7W66MLs0ubi3XMLwAZ2Mmb
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  636725b53c15b04e773fa9fa5a08ae1a
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod
hs-libraries:         HSyesod-1.6.2.1-7W66MLs0ubi3XMLwAZ2Mmb
depends:
    aeson-2.1.2.1-JD8QPsoBF4NC1qVY6ch6us base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-5zFQSWi5xEVBAmxL35th12
    data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb directory-1.3.7.1
    fast-logger-3.2.3-F6uFSsZg53fApTxegWjPy9
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    monad-logger-0.3.42-GMF9gvzPow1E9lLZVRGYka
    shakespeare-2.1.4-Dnanl5d0sWAD8jUS2DDE5V
    streaming-commons-0.2.3.0-2aM6amPe0pHKhsqCppUNcv
    template-haskell-2.19.0.0 text-2.0.2 unix-2.7.3
    unordered-containers-0.2.20-ASGEyX3xTBf3ZK5sYSGlF8
    wai-3.2.4-9ouRC0VqvifDMOi7kU9fdU
    wai-extra-3.1.17-8ibmlHiRh9ZHcEXjBa7mIp
    wai-logger-2.5.0-FdMtwpC5XD8C4YEVb9xtOk
    warp-3.3.30-6ekQ3avvbuT5j5432YK3Fy
    yaml-0.11.11.2-37tw4FuYjIR6RRod391CFN
    yesod-core-1.6.27.1-Ltd2Iw7lYklD0zMvFlIvmS
    yesod-form-1.7.9-1v5Sf4Who9n5TqHvVtXe6e
    yesod-persistent-1.6.0.8-5fU3hxVFJ7Q3sonBgbmbIS

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-1.6.2.1-386-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod
version:              1.6.2.1
visibility:           public
id:                   yesod-1.6.2.1-GbVhQAhFKRQDueLrvjXuPy
key:                  yesod-1.6.2.1-GbVhQAhFKRQDueLrvjXuPy
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  10a08fc1fa33d811f89bb5226418b27e
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod
hs-libraries:         HSyesod-1.6.2.1-GbVhQAhFKRQDueLrvjXuPy
depends:
    aeson-2.1.2.1-JD8QPsoBF4NC1qVY6ch6us base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-5zFQSWi5xEVBAmxL35th12
    data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb directory-1.3.7.1
    fast-logger-3.2.3-F6uFSsZg53fApTxegWjPy9
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    monad-logger-0.3.42-GMF9gvzPow1E9lLZVRGYka
    shakespeare-2.1.4-Dnanl5d0sWAD8jUS2DDE5V
    streaming-commons-0.2.3.0-2aM6amPe0pHKhsqCppUNcv
    template-haskell-2.19.0.0 text-2.0.2 unix-2.7.3
    unordered-containers-0.2.20-ASGEyX3xTBf3ZK5sYSGlF8
    wai-3.2.4-9ouRC0VqvifDMOi7kU9fdU
    wai-extra-3.1.17-8ibmlHiRh9ZHcEXjBa7mIp
    wai-logger-2.5.0-FdMtwpC5XD8C4YEVb9xtOk
    warp-3.3.30-6ekQ3avvbuT5j5432YK3Fy
    yaml-0.11.11.2-37tw4FuYjIR6RRod391CFN
    yesod-core-1.6.27.1-Ltd2Iw7lYklD0zMvFlIvmS
    yesod-form-1.7.9-9W8orfVMeXp4leXvIcytjK
    yesod-persistent-1.6.0.8-3xy0asFEmKMAYLQYhzZNwg

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
